@@ -3,9 +3,9 @@ package Number::ZipCode::JP::Table::Company;
 use strict;
 use warnings;
 
-our $VERSION = '0.20131129';
+our $VERSION = '0.20131227';
 
-# Table last modified: 2013-11-29
+# Table last modified: 2013-12-27
 our %ZIP_TABLE = (
     '001' => '(?:8(?:5(?:[02]1|88)|612))',
     '002' => '(?:850[1-4])',
@@ -24,7 +24,7 @@ our %ZIP_TABLE = (
     '017' => '(?:(?:8(?:5(?:10|67|85|5[05])|686)|029[23]))',
     '018' => '(?:(?:1(?:39[23]|59[56]|79[23]|692)|3(?:59[2356]|39[23]|192)|0(?:49[23]|[16]92|795)|4(?:69[23]|392|494)|5(?:79[23]|292)|2498))',
     '019' => '(?:(?:1(?:397|692)|079[23]|2[16]92))',
-    '020' => '(?:(?:8(?:5(?:2[0-35]|3[0-3]|8[04-68]|0[12578]|1[0-358]|6[0167]|7[0357]|4[034]|5[013578])|6(?:33|41|7[278]|2[02]|6[167]|5[05]|1[0-2]|8[68]|0[1256])|794)|0(?:1(?:8[0-578]|9[2368])|59[2356]|49[56])))',
+    '020' => '(?:(?:8(?:5(?:2[0-35]|3[0-3]|8[04-68]|0[12578]|1[0-358]|6[0167]|7[0357]|4[034]|5[013578])|6(?:33|41|7[278]|2[02]|6[167]|5[05]|1[0-2]|8[68]|0[1256])|794)|0(?:1(?:8[2457]|9[68])|69[0-48]|59[2356]|49[56])))',
     '021' => '(?:8(?:5(?:11|44|55|66|77|0[1-46])|6(?:04|11|33|87)))',
     '022' => '(?:8(?:5(?:12|0[1-578])|602))',
     '023' => '(?:(?:049[23]|1192|8501))',
@@ -103,20 +103,20 @@ our %ZIP_TABLE = (
     '097' => '(?:8(?:5(?:10|85|5[58]|2[57])|6(?:[03]9|[68]6)))',
     '098' => '(?:(?:5(?:[78]92|298|595)|(?:28|62|0[13])92|1(?:69[23]|792)|339[23568]))',
     '099' => '(?:(?:2(?:19[2-8]|49[235]|392)|1(?:49[2568]|19[78]|595)|3(?:29[23]|69[78])|4(?:19[256]|492)|(?:56|65)92|049[245]))',
-    '100' => '(?:(?:8(?:9(?:4[015]|8[0-35-79]|2[0-24-79]|9[46]|3[0137]|1[02-9]|0[1-579]|5[0-3569]|7[0-24-9]|6[0-257-9])|1(?:7[1-3]|3[013589]|6\d|0[2358]|8[125-9]|5[18]|4[014]|1[01357-9]|2[0-3568])|2(?:46|70|5[1-3]|6[02578]|8[2358]|0[13]|1[014-69]|2[278]|3[2-4])|3(?:66|70|5[015]|2[1245]|3[138]|0[237]|4[15]|1[01]|8[038])|6(?:55|2[019]|6[356]|0[1268]|7[67]|1[07]|3[129]|4[049])|5(?:11|4[03]|0[1-35-7]|5[058]|2[02]|6[07]|8[58]|7[57])|4(?:02|56|1[015]|2[0147]|3[09]|4[048]|8[48])|0(?:66|7[07-9]|8[68]|5[01])|79[1589])|6(?:1(?:62|7[0-578]|5[0-2])|2(?:55|77|6[02])|0(?:51|66|80)|75[1-6])|149[28]|3131))',
+    '100' => '(?:(?:8(?:9(?:4[015]|8[0-35-79]|2[0-24-79]|9[46]|3[0137]|1[02-9]|0[1-579]|5[0-3569]|7[0-24-9]|6[0-257-9])|1(?:7[1-3]|3[013589]|6\d|0[2358]|8[125-9]|5[18]|4[014]|1[01357-9]|2[0-3568])|2(?:46|70|5[1-3]|6[02578]|8[2358]|0[13]|1[014-69]|2[278]|3[2-4])|3(?:66|70|5[015]|2[1245]|3[138]|0[237]|4[15]|1[01]|8[038])|6(?:55|2[019]|6[356]|0[1268]|7[67]|1[07]|3[129]|4[049])|5(?:11|4[03]|0[1-35-7]|5[058]|2[02]|6[07]|8[58]|7[57])|4(?:02|5[06]|1[015]|2[0147]|3[09]|4[048]|8[48])|0(?:66|7[07-9]|8[68]|5[01])|79[1589])|6(?:1(?:62|7[0-578]|5[0-2])|2(?:55|77|6[02])|0(?:51|66|80)|75[1-6])|149[28]|3131))',
     '101' => '(?:8(?:3(?:0[1257-9]|4[5-7]|8[01358]|6[02356]|7[0158]|3[0135]|5[0-689]|2[1-8]|1[013-7])|5(?:6[0-2568]|8[1568]|1[0-2459]|7[6-9]|4[2-58]|0[1-46-9]|5[24589]|3[0-5]|2[0-3568])|4(?:7[05-7]|2[1-57]|8[13]|0[57-9]|3[0379]|5[0-4689]|4[13-9]|6[04-9]|1[0-25689])|6(?:8[28]|0[5-79]|1[0-379]|6[2578]|3[0346-8]|5[14-6]|4[1-3568]|2[014-9]|7[026])|9(?:[01]1|50|7[0-37]|4[16]|8[036])|7(?:0[137]|1[0-25-8])|0(?:11|50|77|0[128])|2(?:0[1-4]|1[0359])|101))',
     '102' => '(?:8(?:4(?:5[0-2569]|8[13489]|7[047]|6[0-24-68]|4[057]|2[014679]|0[125-7]|1[014579]|3[0-3578])|1(?:1[0-278]|8[124-8]|5[0-25]|3[0-289]|7[0-25-8]|2[02358]|0[1-359]|4[0-24]|6[016])|6(?:3[0-3579]|4[245]|2[016-8]|8[0589]|7[17-9]|0[1-479]|1[0-47-9]|5[016]|6[06-8])|5(?:0[2-468]|5[024-9]|2[0289]|6[079]|3[0139]|4[013]|8[0458]|1[01568]|7[013578])|3(?:4[19]|1[0134]|3[1-356]|8[1-38]|6[24]|7[0237]|5[0367]|0[1-359]|2[0-24])|2(?:88|5[015]|1[158]|7[257]|2[2568]|3[0-2468]|0[15]|6[0245]|4[016])|0(?:08|30|77|8[0-35]|2[45]|1[125689])|79[58]))',
     '103' => '(?:8(?:2(?:0[1-6]|5[0-259]|1[0-2478]|6[0135]|8[2457]|7[02358]|4[0-3578]|3[0-8]|2[124589])|4(?:7[0-3]|2[2-7]|0[1-57]|4[38]|3[02-57-9]|1[0-79]|6[0-24-6]|8[01467]|5[016])|3(?:7[03]|5[0-2458]|0[136-8]|8[0348]|2[01348]|4[15-7]|1[0137]|6[036]|3[01357-9])|5(?:0[1-367]|8[4-689]|2[0-25]|5[24-68]|6[067]|3[13-8]|4[238]|1[0-2]|7[017])|6(?:40|7[067]|6[068]|8[0469]|5[0-36]|3[1269])|0[01]1))',
-    '104' => '(?:(?:8(?:1(?:2[2-589]|3[0-58]|0[124-689]|5[158]|8[0139]|4[25]|6[1-8]|7[0-24-8]|1[14-8])|4(?:1[035689]|3[013-689]|4[03-578]|8[168]|0[1-8]|[67][068]|5[0156]|2[0-579])|5(?:1[028]|3[0135689]|5[013-689]|4[0468]|7[02]|6[036-8]|2[0136-8]|0[1256]|8[014578])|3(?:7[027-9]|4[04]|1[0-3579]|8[01368]|2[014589]|5[167]|6[05]|3[02358]|0[2-59])|2(?:4[03]|1[0-258]|3[38]|2[28]|0[568]|5[0-35-7]|6[026]|8[0-24589]|7[017])|6(?:5[06]|6[0158]|8[05]|7[08])|0(?:55|77|1[01]|0[1347]))|6241))',
-    '105' => '(?:(?:8(?:4(?:7[0-3]|3[2-7]|0[1-578]|8[2-8]|5[0-35-8]|2[0247-9]|6[01457-9]|4[015-9]|1[0-24-69])|5(?:4[0356]|2[0-357-9]|1[0-2578]|5[02-8]|0[257-9]|8[0-57-9]|7[4-9]|6[0378]|3[0457])|6(?:54|6[0568]|2[136]|1[013-58]|8[035-9]|4[02]|7[078]|3[014]|0[3468])|0(?:20|0[1258]|7[07]|8[58]|5[05]|1[0-2])|3(?:22|1[0-35]|0[15-7]|3[038])|7(?:88|0[127]|1[1267]))|7444))',
+    '104' => '(?:(?:8(?:1(?:2[2-589]|3[0-58]|0[124-689]|5[158]|8[0139]|4[25]|6[1-8]|7[0-24-8]|1[14-7])|4(?:1[035689]|3[013-689]|4[03-578]|8[168]|0[1-8]|[67][068]|5[0156]|2[0-579])|5(?:1[028]|3[0135689]|5[013-689]|4[0468]|7[02]|6[036-8]|2[0136-8]|0[1256]|8[014578])|3(?:7[027-9]|1[0-3579]|8[01368]|4[045]|2[014589]|5[167]|6[05]|3[02358]|0[2-59])|2(?:40|1[0-258]|3[38]|2[28]|0[568]|5[0-35-7]|6[026]|8[0-24589]|7[017])|6(?:5[06]|6[0158]|8[05]|7[08])|0(?:55|77|1[01]|0[1347]))|6241))',
+    '105' => '(?:(?:8(?:4(?:7[0-3]|3[2-7]|0[1-578]|8[2-8]|5[0-35-8]|2[0247-9]|6[01457-9]|4[015-9]|1[0-24-69])|5(?:6[03578]|4[0356]|2[0-357-9]|1[0-2578]|5[02-8]|0[257-9]|8[0-57-9]|7[4-9]|3[0457])|6(?:54|6[0568]|2[136]|1[013-58]|8[035-9]|4[02]|7[078]|3[014]|0[3468])|0(?:20|0[1258]|7[07]|8[58]|5[05]|1[0-2])|3(?:22|1[0-35]|0[15-7]|3[038])|7(?:88|0[127]|1[1267]))|7444))',
     '106' => '(?:(?:8(?:5(?:08|6[0-35-79]|7[136-8]|1[458]|4[13-5]|2[12]|3[1257]|5[0-35689]|8[0157-9])|6(?:77|6[158]|4[0-2489]|5[25]|1[168]|0[18]|2[0256]|3[069])|0(?:[01]1|39)|401|797)|6(?:1(?:61|88)|06[06])))',
-    '107' => '(?:8(?:5(?:32|8[135]|5[026-8]|2[0-2578]|7[079]|6[037]|0[258]|1[15]|4[56])|6(?:50|8[06]|2[03578]|0[14]|1[5-79]|7[46]|3[0-3689]|6[68])|4(?:34|56|77|2[03]|0[134]|1[0-24679]|8[24]|4[08]|6[06-8])|3(?:55|4[028]|7[013]|2[0346]|6[09]|8[048]|3[026])|0(?:06|60|77)))',
-    '108' => '(?:(?:8(?:5(?:7[1358]|1[0-25]|4[03-578]|6[048]|3[0236]|0[12579]|5[0-36-9]|2[035]|8[0-3568])|3(?:2[25689]|3[0348]|5[058]|8[0134689]|1[35]|6[01]|4[15]|7[02389]|0[3578])|2(?:7[056]|0[128]|8[02]|3[0-4]|5[05]|2[12]|4[0-2]|1[017])|4(?:[56]6|85|0[347]|3[09]|2[013-5]|7[078]|1[014-7]|4[48])|6(?:50|3[2356]|0[1267]|1[0-25-7]|2[28]|4[0-268])|0(?:[17]1|[25]0|8[08]|0[15])|7(?:1[03]|0[137])|117)|63(?:50|63)))',
+    '107' => '(?:8(?:5(?:32|8[135]|5[026-8]|2[0-2578]|7[07]|6[037]|0[258]|1[15]|4[56])|6(?:50|8[06]|2[03578]|0[14]|1[5-79]|7[46]|3[0-3689]|6[68])|4(?:20|34|56|77|0[134]|1[0-24679]|8[24]|4[08]|6[06-8])|3(?:55|4[028]|7[013]|2[0346]|6[09]|8[048]|3[026])|0(?:06|60|77)))',
+    '108' => '(?:(?:8(?:5(?:7[1358]|1[0-25]|4[03-578]|5[0-35-9]|6[048]|3[0236]|0[12579]|2[035]|8[0-3568])|3(?:2[25689]|3[0348]|5[058]|8[0134689]|1[35]|6[01]|4[15]|7[02389]|0[3578])|2(?:7[056]|0[128]|8[02]|3[0-4]|5[05]|2[12]|4[0-2]|1[017])|4(?:[56]6|85|0[347]|3[09]|2[013-5]|7[078]|1[014-7]|4[48])|6(?:50|3[2356]|0[1267]|1[0-25-7]|2[28]|4[0-268])|0(?:[17]1|[25]0|8[08]|0[15])|7(?:1[03]|0[137])|117)|63(?:50|63)))',
     '109' => '(?:8792)',
     '110' => '(?:8(?:5(?:8[2-468]|6[0-25-7]|5[0589]|4[013689]|7[5-8]|3[0-4679]|0[1-3579]|1[01357]|2[0-24])|6(?:97|2[0-2568]|6[0259]|5[34]|4[245]|3[0158]|0[259]|8[015-7]|1[03-589]|7[35-8])|7(?:45|8[027]|1[2-6]|3[36]|0[68]|2[1-35])|408|807))',
-    '111' => '(?:8(?:6(?:3[01379]|5[056]|[12][0-258]|7[6-8]|8[1368]|4[02]|0[2568]|6[16])|5(?:43|1[0-258]|8[058]|5[568]|3[0-49]|7[57]|6[0167]|2[125]|0[125-8])|7(?:[56]5|[89]8|21|0[178]|1[01])|081))',
+    '111' => '(?:8(?:6(?:3[01379]|5[056]|[12][0-258]|7[6-8]|8[1368]|4[02]|0[2568]|6[16])|5(?:43|1[0-258]|8[058]|5[568]|3[0-49]|7[57]|6[0167]|2[125]|0[125-8])|7(?:[56]5|21|98|0[178]|1[01])|081))',
     '112' => '(?:8(?:6(?:90|0[1467]|2[02579]|4[24]|7[01578]|5[0-57]|8[0-578]|3[02-5]|1[0-28]|6[02-478])|5(?:4[018]|6[02369]|3[138]|0[125689]|2[248]|5[015-8]|1[0-24-6]|8[035]|7[02-6])|7(?:10|33|0[12])|0(?:[01]1|88)))',
-    '113' => '(?:8(?:4(?:8[348]|4[148]|7[1479]|2[0-3]|1[0-358]|6[2-6]|3[13-5]|5[0169]|0[1248])|5(?:0[13-579]|6[0-46]|4[1369]|1[0379]|2[014-6]|3[04-6]|5[1356])|6(?:6[0-3]|3[38]|5[04-8]|8[167]|1[0-2]|0[1-48])|7(?:01|1[129])|311))',
+    '113' => '(?:8(?:4(?:8[348]|4[148]|7[1479]|2[0-3]|1[0-358]|6[2-6]|3[13-5]|5[0169]|0[1248])|5(?:70|0[13-579]|6[0-46]|4[1369]|1[0379]|2[014-6]|3[04-6]|5[1356])|6(?:6[0-3]|3[38]|5[04-8]|8[167]|1[0-2]|0[1-48])|7(?:01|1[129])|311))',
     '114' => '(?:8(?:5(?:95|0[1-35-8]|8[013-58]|6[0-25]|4[0135]|7[147]|2[0-2468]|5[02-57]|3[0-24589]|1[02457-9])|6(?:11|86|0[2-6])))',
     '115' => '(?:8(?:5(?:55|67|8[568]|1[01]|2[49])|622|711))',
     '116' => '(?:8(?:5(?:71|6[127]|2[1-4]|5[0-246]|8[014-8]|4[013689]|0[1-3578]|3[237])|611))',
@@ -126,7 +126,7 @@ our %ZIP_TABLE = (
     '124' => '(?:85(?:60|77|2[04]|3[3589]|0[1-39]|8[58]|5[05]|1[01]))',
     '125' => '(?:8(?:5(?:1[1-57]|0[3-8]|8[58]|2[026])|601))',
     '130' => '(?:8(?:5(?:7[057]|8[0348]|3[013-589]|4[358]|6[15-7]|5[4-8]|0[13-9]|1[0-8]|2[0258])|6(?:25|86|7[17]|3[67]|5[05]|6[068]|1[15]|0[1-689]|4[024])|7(?:[12]0|0[16])))',
-    '131' => '(?:8(?:5(?:40|65|1[0-389]|3[03]|2[0467]|8[458]|5[05]|0[13-57-9])|634|711))',
+    '131' => '(?:8(?:5(?:40|65|1[0-389]|3[03]|2[0467]|8[458]|5[05]|0[13-57-9])|139|634|711))',
     '132' => '(?:8(?:5(?:33|85|5[015]|0[137]|6[27])|6(?:01|74|[68][68])|7(?:11|3[029])))',
     '133' => '(?:8(?:5(?:[01]1|8[05]|5[238])|70[46]))',
     '134' => '(?:8(?:5(?:[15]5|20|33|7[05-7]|8[568]|0[237])|6(?:22|86|[14][02]|0[1-39]|3[01])|702))',
@@ -172,13 +172,13 @@ our %ZIP_TABLE = (
     '181' => '(?:8(?:5(?:41|3[135]|7[17]|0[35]|1[0178]|8[5-8]|5[15]|2[0-28])|6(?:22|33|48|1[14]|0[18])|001))',
     '182' => '(?:8(?:5(?:08|67|70|85|2[025]|5[58]|1[0-2])|6(?:21|86|0[12])|00[16]))',
     '183' => '(?:8(?:5(?:61|2[124-689]|1[1-46]|5[013]|3[0249]|4[0189]|0[1256])|70[1-35-7]))',
-    '184' => '(?:8(?:5(?:[34]3|22|95|8[158]|5[58]|7[57]|0[1-58]|1[01])|795))',
+    '184' => '(?:8(?:5(?:[34]3|22|95|5[58]|7[57]|0[1-58]|8[1458]|1[01])|795))',
     '185' => '(?:8(?:5(?:33|40|6[27]|0[126]|1[01])|601|795))',
     '186' => '(?:8(?:6(?:50|0[1-3]|1[19]|8[068]|6[68])|5(?:01|19|85)|79[78]|001))',
     '187' => '(?:8(?:5(?:40|0[2357]|3[13]|5[1358]|2[02]|6[07]|8[1578]|7[078]|1[0-28])|(?:61|70)1))',
     '188' => '(?:8(?:5(?:[58]5|11)|6(?:66|80)|701))',
     '189' => '(?:85(?:[01]1|20|85|5[05]))',
-    '190' => '(?:(?:8(?:5(?:2[028]|3[015-79]|5[013-578]|6[0-256]|8[1-3689]|0[135-9]|7[1-358]|1[013-9]|4[034])|6(?:66|8[0168]))|129[2357]|0192))',
+    '190' => '(?:(?:8(?:5(?:2[028]|3[015-79]|5[013-578]|0[135-8]|6[0-256]|8[1-3689]|7[1-358]|1[013-9]|4[034])|6(?:09|66|8[0168]))|129[2357]|0192))',
     '191' => '(?:8(?:5(?:20|0[1-35-79]|1[0-2])|6(?:60|86)))',
     '192' => '(?:(?:8(?:5(?:77|85|2[025]|6[28]|5[1368]|3[235-7]|1[0258]|0[125-8])|6(?:11|22|33|5[05]|4[48])|702)|0(?:9(?:9[1-4]|8[1-3689])|39[2-7])))',
     '193' => '(?:(?:8(?:5(?:[57]0|33|2[05]|1[01]|0[15])|6[68]6)|09(?:85|9[178])))',
@@ -195,7 +195,7 @@ our %ZIP_TABLE = (
     '206' => '(?:8(?:5(?:30|77|4[03]|2[025]|8[568]|6[167]|0[235]|5[05]|1[125])|6(?:[01]1|[68]6)))',
     '207' => '(?:85(?:[18]5|01))',
     '208' => '(?:85(?:[58]5|0[1-3]))',
-    '210' => '(?:(?:8(?:5(?:2[1-3]|6[0259]|5[27-9]|3[1278]|0[1246]|7[0167]|8[36]|1[125]|4[014578])|6(?:66|0[14]|8[016]))|9(?:5(?:[06]7|11|26|55|3[03]|8[28])|650)))',
+    '210' => '(?:(?:8(?:5(?:2[1-3]|6[0259]|3[1278]|0[1246]|7[0167]|8[36]|1[125]|5[127-9]|4[014578])|6(?:66|0[14]|8[016]))|9(?:5(?:[06]7|11|26|55|3[03]|8[28])|650)))',
     '211' => '(?:8(?:5(?:[2-4]0|66|7[07]|8[58]|5[05]|1[01]|0[125])|6(?:01|75|1[19]|6[68])))',
     '212' => '(?:8(?:5(?:44|90|8[1-589]|1[13]|6[03467]|2[05]|7[0267]|5[1457]|3[01]|0[1-3589])|602))',
     '213' => '(?:85(?:66|2[0-35]|0[2357]|5[01389]|3[35]|7[0367]|8[015-9]|1[125]|4[56]))',
@@ -344,7 +344,7 @@ our %ZIP_TABLE = (
     '368' => '(?:(?:8(?:6(?:66|8[06])|50[125])|0(?:19[235]|292)))',
     '369' => '(?:(?:1(?:29[2358]|89[2-5]|19[235]|59[236]|[34]92|998)|0(?:29[2357]|19[258]|39[235])))',
     '370' => '(?:(?:8(?:5(?:[01]1|[68]5|22|43|3[17]|5[05])|6(?:[01]1|22|86|6[68]))|1(?:39[2-6]|19[2356]|29[23]|592)|0(?:59[568]|49[25]|193|692|795)|2(?:39[23568]|49[58]|[12]92)|3(?:59[2-4]|[146]92|39[23])))',
-    '371' => '(?:(?:8(?:5(?:2[02578]|0[1-578]|1[0-7]|8[0568]|4[38]|3[01359]|5[015-7]|7[023]|6[017])|6(?:[36]6|01|40|77|1[167]|2[05]|8[68]))|0(?:29[2-4]|192)))',
+    '371' => '(?:(?:8(?:5(?:0[1-578]|1[0-7]|8[0568]|2[0-2578]|4[38]|3[01359]|5[015-7]|7[023]|6[017])|6(?:[36]6|01|40|77|1[167]|2[05]|8[68]))|0(?:29[2-4]|192)))',
     '372' => '(?:8(?:5(?:58|67|8[058]|0[128])|686))',
     '373' => '(?:8(?:5(?:21|78|0[1589]|1[0135]|8[58]|5[0157]|3[01]|6[017])|6(?:01|22|6[06]|8[68]|1[01])|718))',
     '374' => '(?:(?:8(?:5(?:01|20|33|55|77|88|1[0-28])|6(?:11|22|40|86|0[18]))|019[23]))',
@@ -353,7 +353,7 @@ our %ZIP_TABLE = (
     '377' => '(?:(?:0(?:8(?:8[23]|9[2-46-8])|19[235]|29[2-4]|39[25]|49[24]|792)|8(?:5(?:[67]7|20|33|55|1[013]|0[1-38]|8[58])|616)|1(?:79[2-7]|39[235]|59[3-5]|69[235])))',
     '378' => '(?:(?:0498|8501))',
     '379' => '(?:(?:2(?:1(?:8[01457]|9[2-578])|39[258]|29[28])|1(?:[16]92|[24]98|393)|0(?:19[2356]|292)))',
-    '380' => '(?:8(?:5(?:8[013-689]|5[0-2578]|7[0-35-7]|0[1-8]|6[015-8]|2[0-24-6]|4[03-6]|1[0-25689]|3[013-9])|6(?:55|0[158]|2[25]|3[0359]|8[268]|6[068]|4[08]|1[0-24])|79[4-8]))',
+    '380' => '(?:8(?:5(?:8[013-689]|5[0-2578]|0[1-8]|7[0235-7]|6[015-8]|2[0-24-6]|4[03-6]|1[0-25689]|3[013-9])|6(?:55|0[158]|2[25]|3[0359]|8[268]|6[068]|4[08]|1[0-24])|79[4-8]))',
     '381' => '(?:(?:8(?:5(?:1[015]|[67][07]|3[09]|0[138]|4[58]|2[05]|8[08]|5[68])|6(?:02|86)|793)|0(?:29[23578]|19[23]|49[78])|22(?:8[0-35-8]|9[258])|4(?:19[23]|393)))',
     '382' => '(?:8(?:5(?:33|55|0[128]|8[578]|1[0-2])|633))',
     '383' => '(?:8(?:5(?:55|67|8[158]|[01][15])|6(?:14|86)))',
@@ -478,7 +478,7 @@ our %ZIP_TABLE = (
     '506' => '(?:(?:8(?:6(?:66|78|0[13]|8[6-8])|5(?:77|85|0[26]|5[05]))|1(?:49[23568]|19[56]|392)|019[24]|2192))',
     '507' => '(?:8(?:5(?:[16]1|33|2[237])|6(?:50|0[1-3578])|70[1-3568]))',
     '508' => '(?:(?:8(?:5(?:[58]5|11|0[0-2])|6(?:[68]6|11))|0(?:292|494)))',
-    '509' => '(?:(?:7(?:79[2357]|[258]92|49[23]|69[23])|1(?:39[2-6]|19[23]|69[25]|492)|0(?:29[24578]|19[278]|393|492)|2(?:59[2358]|29[235])|5(?:19[2358]|292|494)|9(?:29[23568]|19[25])|(?:83|4[1-3])92|3(?:195|292)|619[2-6]))',
+    '509' => '(?:(?:7(?:79[2357]|[258]92|49[23]|69[23])|1(?:39[2-6]|19[23]|69[25]|492)|0(?:29[24-8]|19[278]|393|492)|2(?:59[2358]|29[235])|5(?:19[2358]|292|494)|9(?:29[23568]|19[25])|(?:83|4[1-3])92|3(?:195|292)|619[2-6]))',
     '510' => '(?:(?:8(?:5(?:[34]0|5[0257]|0[3-5]|8[058]|1[0-25]|7[57]|2[0258]|6[0-27])|6(?:[23]1|42|66|70|5[15]|1[56]|0[145]))|0(?:29[2-58]|[13]92)|1292))',
     '511' => '(?:(?:8(?:5(?:[67]7|02|33|5[058]|8[58]|1[01])|6(?:[68]6|01|78)|7(?:11|98))|0(?:29[2-68]|19[28]|59[23]|492)|1192))',
     '512' => '(?:85(?:12|38|50))',
@@ -858,7 +858,7 @@ our %ZIP_TABLE = (
     '899' => '(?:(?:5(?:29[2-4]|69[348]|19[23]|49[25]|392)|6(?:49[2-5]|19[23]|29[23]|592)|(?:3[14]|7[146]|8[16])92|2(?:59[2-6]|[127]92)|4(?:39[2-6]|[12]92)|0(?:29[23578]|492)|1(?:395|498|696)))',
     '900' => '(?:8(?:5(?:5\d|2[02457]|4[03-578]|6[07]|3[013-5]|0[13-5]|7[01578]|8[01568]|1[0-467])|6(?:10|66|78|5[0146]|0[1-59]|8[68])|7(?:[01]1|35|9[4-7])))',
     '901' => '(?:(?:2(?:5(?:40|88|97|6[0679]|1[0-25]|5[0-35-9]|0[126]|2[0156]|3[01])|6(?:86|0[127]|1[01])|7(?:01|10|33)|49[2356]|39[25])|0(?:49[2-6]|19[2-4]|29[245]|39[23]|592|695)|3(?:[679]92|19[23]|59[25]|496|895)|1(?:19[2356]|39[23]|[24]92|595)))',
-    '902' => '(?:85(?:21|8[58]|5[05]|1[0-2]|7[01]))',
+    '902' => '(?:85(?:21|1[0-3]|8[58]|5[05]|7[01]))',
     '903' => '(?:(?:02(?:20|1[013-578]|0[13-7])|860[1-3]))',
     '904' => '(?:(?:0(?:49[2-7]|39[2-58]|19[2-5]|29[35])|2(?:19[2-6]|39[2-4]|29[23])|8(?:5(?:[01]1|85)|686)|1(?:29[2-4]|[13]92)))',
     '905' => '(?:(?:0(?:59[2-6]|79[2-6]|[24]92|695)|8(?:5(?:01|12|40|85)|6(?:11|68))|1(?:[23]92|495)|2192))',
@@ -869,14 +869,14 @@ our %ZIP_TABLE = (
     '912' => '(?:(?:8(?:5(?:[58]5|24|40|67)|6[68]6)|0292))',
     '913' => '(?:8(?:5(?:[01]1|33|55|77|8[58])|611))',
     '914' => '(?:(?:8(?:5(?:[14]0|24|67|5[058]|8[05]|0[12])|6(?:09|66|8[68]))|019[258]))',
-    '915' => '(?:(?:8(?:5(?:[58]5|01|3[03]|1[01])|666)|0292|1195))',
+    '915' => '(?:(?:8(?:5(?:01|55|3[03]|8[58]|1[01])|666)|0292|1195))',
     '916' => '(?:(?:8(?:5(?:67|5[058]|8[58]|1[05]|0[1578])|6(?:[468]6|01))|0(?:29[235]|[14]92)|1198))',
     '917' => '(?:(?:8(?:5(?:[24]4|33|77|6[17]|5[058]|1[12]|0[57]|8[0458])|6(?:01|86))|0(?:29[378]|39[38]|198)))',
     '918' => '(?:8(?:5(?:4[03]|5[0568]|6[05-8]|1[0158]|7[0578]|2[0235]|3[037]|0[1-358]|8[03568])|68[168]))',
     '919' => '(?:(?:0(?:59[24578]|69[2578]|[124]92|898)|1(?:39[235-7]|[15]92)|2(?:29[2-4]|392)))',
     '920' => '(?:(?:8(?:5(?:0[1-9]|4[0134]|2[0-25]|3[0135-9]|7[0357]|1[0-3578]|5[0-8]|6[0135-8]|8[035-8])|6(?:2[0-356]|5[04-8]|0[125-79]|3[0-37-9]|7[0146-8]|8[01568]|4[0-248]|6[0156]|1[0-69])|7(?:[67]7|30|0[17]|9[13-7]|2[0-289]|1[0189]))|0(?:3(?:8[135-8]|9[23568])|29[235]|192)|1(?:1(?:92|8[0-245])|39[2367])|2(?:39[2-5]|19[256])|3198))',
     '921' => '(?:8(?:5(?:6[0-245]|5[025]|1[0-2578]|3[0-269]|8[0-489]|0[15-8]|2[035-79]|4[1468]|7[1-79])|6(?:01|50|3[079]|1[126]|2[01])|798))',
-    '922' => '(?:(?:8(?:5(?:01|30|66|2[25]|8[58]|5[05]|1[01])|6(?:09|11|22|50|78|86))|0(?:29[2-578]|19[23]|49[57]|595)))',
+    '922' => '(?:(?:8(?:5(?:01|30|66|2[25]|8[58]|5[05]|1[01])|6(?:09|11|22|50|78|86))|0(?:29[3-578]|19[23]|49[57]|595)))',
     '923' => '(?:(?:8(?:5(?:5[0-257]|8[0168]|3[013]|2[0158]|0[1-357]|6[067]|7[078]|4[14-6]|1[01])|6(?:50|66|2[06]|4[2-46]|1[0156]|8[68]|0[135689]|3[039]))|1(?:29[2-7]|198)|039[238]))',
     '924' => '(?:8(?:5(?:22|33|44|77|6[06]|8[058]|5[58]|1[01])|68[68]))',
     '925' => '(?:(?:8(?:5(?:11|30|85|6[67]|0[12568]|5[05]|2[15])|6(?:[12]0|09|88))|0(?:19[38]|392|498)))',
@@ -886,7 +886,7 @@ our %ZIP_TABLE = (
     '929' => '(?:(?:1(?:39[2-7]|19[23568]|49[2-4]|[6-8]92|29[23])|0(?:49[2-5]|19[238]|29[26]|39[23])|2(?:19[25]|[23]92)))',
     '930' => '(?:(?:8(?:5(?:4[03-58]|6[0-35-7]|3[0-35-9]|2[0-256]|0[124-9]|8[0135-9]|1[0-35-8]|7[013578]|5[024-68])|6(?:5[06]|0[3-5]|4[24]|3[067]|1[01]|8[016]|6[06-8])|798)|0(?:19[3-68]|39[3-57]|29[238])|1(?:29[258]|392)|2198))',
     '931' => '(?:8(?:5(?:33|62|2[23]|4[03]|7[17]|0[128]|[58][58]|1[0157])|6(?:01|88)))',
-    '932' => '(?:(?:8(?:5(?:33|40|75|1[0-258]|5[0158]|6[27]|8[58]|0[1-358]|2[0258])|611)|0(?:39[23568]|19[38]|29[28])))',
+    '932' => '(?:(?:8(?:5(?:33|40|67|75|1[0-258]|5[0158]|8[58]|0[1-358]|2[0258])|611)|0(?:39[23568]|19[38]|29[28])))',
     '933' => '(?:(?:8(?:5(?:4[03]|6[367]|8[58]|1[01568]|0[126-8]|3[0-3578]|5[08]|2[035-8])|6(?:[28]8|66|0[1-356]|1[01])|7(?:77|88))|0(?:39[235-7]|19[235]|29[235])))',
     '934' => '(?:8(?:5(?:22|77|6[78]|3[14]|[58][058]|0[12]|1[15])|6(?:[15]1|8[68])))',
     '935' => '(?:(?:8(?:5(?:01|55|3[15])|6(?:01|86))|0492))',
